stalker.core.models.Asset
=========================

.. inheritance-diagram::
     stalker.core.models.Asset
     :parts: 1

.. currentmodule:: stalker.core.models

.. autoclass:: Asset
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Asset.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Asset.code
      ~Asset.created_by
      ~Asset.date_created
      ~Asset.date_updated
      ~Asset.description
      ~Asset.name
      ~Asset.nice_name
      ~Asset.notes
      ~Asset.project
      ~Asset.references
      ~Asset.shots
      ~Asset.status
      ~Asset.status_list
      ~Asset.tags
      ~Asset.tasks
      ~Asset.type
      ~Asset.updated_by
   
   